Feature 10339 - Enhanced Alarm Mgmt. (SOL005 FM Interface)

Change-Id: Iea141198dbde8ec2485f868511d803e65f3276f6
Signed-off-by: Atul Agarwal <atul.agarwal@altran.com>
diff --git a/osm_mon/server/service.py b/osm_mon/server/service.py
index 94bdf4e..584a42f 100755
--- a/osm_mon/server/service.py
+++ b/osm_mon/server/service.py
@@ -41,11 +41,12 @@
         severity: str,
         statistic: str,
         metric_name: str,
+        action: str,
         tags: dict,
     ) -> Alarm:
         log.debug("create_alarm")
         alarm = Alarm(
             name, severity, threshold, operation, statistic, metric_name, tags
         )
         self.common_db.create_alarm(alarm)
         log.info("Alarm %s created", alarm.name)
@@ -41,11 +41,12 @@
         log.debug("create_alarm")
         alarm = Alarm(
-            name, severity, threshold, operation, statistic, metric_name, tags
+            name, severity, threshold, operation, statistic, metric_name, action, tags
         )
         self.common_db.create_alarm(alarm)